@@ -6,6 +6,7 @@ from .exceptions import CrudException, InvalidPayloadException, ItemNotFoundExce
 from .mapper import ConstructorMapper, LambdaMapper, Mapper, ToFunctionArgsMapper
 from .repository import Repository
 
+GenericBaseRepository = Repository
 __all__ = [
     # Base classes
     "Repository",
@@ -24,11 +25,19 @@ __all__ = [
 ]
 
 try:
-    from .database import DatabaseRepository, SqlalchemyMappedRepository
+    from .database import (
+        DatabaseRepository,
+        SqlalchemyMappedRepository,
+        SqlalchemyModelRepository,
+    )
 except ImportError:  # pragma nocover
     pass
 else:
-    __all__ += ["DatabaseRepository", "SqlalchemyMappedRepository"]
+    __all__ += [
+        "DatabaseRepository",
+        "SqlalchemyMappedRepository",
+        "SqlalchemyModelRepository",
+    ]
 
 try:
     from .http import HttpRepository
